<?php
defined( 'ABSPATH' ) OR exit;
/*
  Plugin Name: GI-Catalog
  Plugin URI: http://www.glareofislam.com/softwares/gicatalog.html
  Description: A great solution for institutions/organizations to easily organize their course materials, FAQs, fatawa into groups, categories, tabs & accordions.
  Version: 1.0
  Author: Zishan Javaid
  Author URI: http://www.glareofislam.com
  License: GPL v2
 */

/*
  Copyright (c) 2014 Zishan Javaid

  Permission is hereby granted under GPL v2, free of charge, to any person obtaining a copy
  of this software and associated documentation files (the "Software"), to deal
  in the Software without restriction, including without limitation the rights
  to use, copy, modify, merge, publish, distribute, sublicense, and/or sell
  copies of the Software, and to permit persons to whom the Software is
  furnished to do so, subject to the following conditions:

  The above copyright notice and this permission notice shall be included in
  all copies or substantial portions of the Software.

  THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR
  IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY,
  FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE
  AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER
  LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING FROM,
  OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN
  THE SOFTWARE.
 */

class GI_Catalog {
    const GICATALOG_DB_VERSION = 1.0;
    
    function __construct() {
        add_action('plugins_loaded', array(&$this, 'constants'), 1);

        /* Internationalize the text strings used. */
        //add_action( 'plugins_loaded', array( &$this, 'i18n' ), 2 );

        /* Load the functions files. */
        add_action( 'plugins_loaded', array( &$this, 'includes' ), 3 );

        add_action('init', array(&$this, 'init'));

        add_action( 'plugins_loaded', array( &$this, 'gicatalog_update_db_check' ), 4 );

        register_activation_hook(__FILE__, array(&$this, 'gicatalog_install'));
    }

    public static function constants() {
        global $wpdb;
        
        
        /* Set constant path to the giml plugin directory. */
        define('GICATALOG_DIR', trailingslashit(plugin_dir_path(__FILE__)));

        /* Set constant path to the giml plugin URL. */
        define('GICATALOG_URI', trailingslashit(plugin_dir_url(__FILE__)));

        define('GICATALOG_IMAGE_UPLOAD_URI', GICATALOG_URI . 'images/upload/');
        define('GICATALOG_IMAGE_UPLOAD_DIR', GICATALOG_DIR . trailingslashit('images/upload'));
        
        /* Set the constant path to the giml includes directory. */
        define('GICATALOG_INCLUDES', GICATALOG_DIR . trailingslashit('includes'));

        define('GICATALOG_BASENAME', plugin_basename(__FILE__));
        define('GICATALOG_PLUGIN_ABSPATH', __FILE__);
        
        define('GICATALOG_NONCE_NAME', 'gi-catalog');
        define('GICATALOG_NONCE', wp_create_nonce(GICATALOG_NONCE_NAME));
        
    }

    public static function includes() {
        require_once( GICATALOG_INCLUDES . 'base/GI_Catalog_Base.php' );
        require_once(GICATALOG_INCLUDES . 'GI_Catalog_Widget.php');        
    }

    public static function init() {
        
        if (is_admin()) {
            require_once( GICATALOG_INCLUDES . 'GI_Catalog_Admin.php' );
            new GI_Catalog_Admin();
        }else{
            require_once( GICATALOG_INCLUDES . 'GI_Catalog_Shortcode.php' );
            new GI_Catalog_Shortcode();
        }
    }

    public static function gicatalog_install() {
        
        $installed_ver = get_site_option("gicatalog_db_version");

        require_once( ABSPATH . 'wp-admin/includes/upgrade.php' );

        if (!$installed_ver) {
            $sql = "CREATE TABLE `" . GICATALOG_TABLE_PREFIX . "group` (
		  `groupid` int(11) NOT NULL AUTO_INCREMENT,
		  `groupname` tinytext NOT NULL,
		  `groupcss` tinytext,
                  `groupdirection` varchar(3) DEFAULT 'ltr',
		  `groupcreateddate` datetime NOT NULL,
		  `groupupdateddate` timestamp NOT NULL DEFAULT '0000-00-00 00:00:00' ON UPDATE CURRENT_TIMESTAMP,
		  PRIMARY KEY (`groupid`)
		) ENGINE=InnoDB  DEFAULT CHARSET=utf8;";
            dbDelta($sql);
            
            $sql = "CREATE TABLE `" . GICATALOG_TABLE_PREFIX . "category` (
		  `categoryid` int(11) NOT NULL AUTO_INCREMENT,
                  `groupid` int(11) NOT NULL,
		  `categoryname` tinytext NOT NULL,
		  `categorycss` tinytext,
                  `categorydirection` varchar(3) DEFAULT 'ltr',
                  `categorysortorder` int(11) DEFAULT 10,
                  `categorycontent` longtext,
		  `categorycreateddate` datetime NOT NULL,
		  `categoryupdateddate` timestamp NOT NULL DEFAULT '0000-00-00 00:00:00' ON UPDATE CURRENT_TIMESTAMP,
                  `subcategoryid` int(11),
		  PRIMARY KEY (`categoryid`),
                  KEY `GROUP_CATEGORY_ID` (`groupid`)
		) ENGINE=InnoDB  DEFAULT CHARSET=utf8;";
            dbDelta($sql);
            
            $sql = "ALTER TABLE `" . GICATALOG_TABLE_PREFIX . "category`
		  ADD CONSTRAINT `GROUP_CATEGORY_ID` FOREIGN KEY (`groupid`) REFERENCES `" . GICATALOG_TABLE_PREFIX . "group` (`groupid`) ON DELETE CASCADE ON UPDATE NO ACTION;";
            dbDelta($sql);
            
            $sql = "ALTER TABLE `" . GICATALOG_TABLE_PREFIX . "category`
		  ADD CONSTRAINT `CATEGORY_CATEGORY_ID` FOREIGN KEY (`subcategoryid`) REFERENCES `" . GICATALOG_TABLE_PREFIX . "category` (`categoryid`) ON DELETE CASCADE ON UPDATE NO ACTION;";
            dbDelta($sql);
            
            update_site_option("gicatalog_db_version", self::GICATALOG_DB_VERSION);
            update_site_option('gicatalog_disable_jqueryui_css', 'false');
            update_site_option('gicatalog_disable_bootstrap_css', 'false');
            update_site_option('gicatalog_fb_app_id', "");
            update_site_option('gicatalog_fb_media_type', "website");
            update_site_option('gicatalog_fb_image', "");
			update_site_option('gicatalog_email_from', 'WordPress');
			$sitename = strtolower( $_SERVER['SERVER_NAME'] );
			if ( substr( $sitename, 0, 4 ) == 'www.' ) {
				$sitename = substr( $sitename, 4 );
			}
			update_site_option('gicatalog_email_address', 'wordpress@' . $sitename);
            update_site_option('gicatalog_email_subject', 'Content shared using GI-Catalog plugin');
            update_site_option('gicatalog_email_template', "<div><b>[HEADER]</b></div>\n<div>[CONTENT]</div>");
        }
    }
    
    private static function gicatalog_update() {
        
    }
    
    public static function gicatalog_update_db_check() {
        global $wpdb;
        if ((get_site_option('gicatalog_db_version'))) {
            if (floatval(get_site_option('gicatalog_db_version')) < floatval(self::GICATALOG_DB_VERSION)) {
                /*$sql = "ALTER TABLE `" . GICATALOG_TABLE_PREFIX . "category` 
                        ADD COLUMN `categorycontent` LONGTEXT NULL AFTER `categorysortorder`;";
                $wpdb->query($sql);

                update_site_option("gicatalog_db_version", self::GICATALOG_DB_VERSION);
                
                self::gicatalog_update();*/
            }
        }
    }

    

}

global $wpdb;

define('GICATALOG_TABLE_PREFIX', $wpdb->prefix . "gicatalog_");

new GI_Catalog();
?>