<?php

defined('ABSPATH') OR exit;

/**
 * Description of GI_Catalog_Admin
 *
 * @author Zishan J.
 */
class GI_Catalog_Admin extends GI_Catalog_Base {

    private static $catalogs;

    function __construct() {
        
        
        add_action('admin_init', array(&$this, 'gicatalog_admin_init'));
        add_action('admin_menu', array(&$this, 'gicatalog_admin_menu'));
        
    }

    public static function gicatalog_admin_init() {
        global $wp_version;

        $plugin_data = get_plugin_data(GICATALOG_PLUGIN_ABSPATH, false);

        If (version_compare($wp_version, '3.6', '<')) {
            if (is_plugin_active(GICATALOG_BASENAME)) {
                deactivate_plugins(GICATALOG_BASENAME);
                wp_die("'" . $plugin_data['Name'] . "' requires WordPress 3.6 or higher! Deactivating plugin.<br /><br />Back to <a href='" . admin_url() . "'>WordPress admin</a>.");
            }
        }

        include(GICATALOG_INCLUDES . 'models/GI_Catalog_Group.php');
        include(GICATALOG_INCLUDES . 'models/GI_Catalog_Category.php');

        $pages_with_editor_button = array('post.php', 'post-new.php');
        foreach ($pages_with_editor_button as $editor_page) {
            add_action("load-{$editor_page}", array(__CLASS__, 'gicatalog_add_editor_buttons'));
        }
        
        add_action( 'load-plugins.php', array(__CLASS__, 'gicatalog_plugins_page') );
        
        self::gicatalog_load_admin_actions();
    }

    public static function gicatalog_plugins_page() {
        add_filter( 'plugin_action_links_' . GICATALOG_BASENAME, array(__CLASS__, 'gicatalog_add_plugin_action_links') );
        add_filter( 'plugin_row_meta', array(__CLASS__, 'gicatalog_add_description_row_meta'), 10, 2 );
    }

    public static function gicatalog_add_description_row_meta( array $links, $file ) {
         if (GICATALOG_BASENAME == $file) {
            //$links[] = '<a href="http://glareofislam.com/faq/" title="' . esc_attr__('Frequently Asked Questions', 'giml') . '">' . __('FAQ', 'giml') . '</a>';
            $params['page'] = 'gi-catalog&tab=about';
            $url = add_query_arg( $params, admin_url( 'options-general.php' ) );
            $links[] = '<a href="http://wordpress.org/support/plugin/gi-catalog">' . __('Support', 'gicatalog') . '</a>';
            $links[] = '<a href="https://www.paypal.com/cgi-bin/webscr?cmd=_s-xclick&hosted_button_id=EPRAWSTXCGTP4" title="' . esc_attr__('Support GI-Catalog with your donation!', 'gicatalog') . '"><strong>' . __('Donate', 'gicatalog') . '</strong></a>';
        }
        return $links;
    }

    public static function gicatalog_add_plugin_action_links(array $links) {
        $params['page'] = 'gi-catalog';
        $url = add_query_arg( $params, admin_url( 'options-general.php' ) );
        $links[] = '<a href="' . $url . '">' . __( 'Plugin page', 'gicatalog' ) . '</a>';
        return $links;
    }

    public static function gicatalog_add_editor_buttons() {
        add_action('admin_print_footer_scripts', array(__CLASS__, 'gicatalog_shortcode_html'));
        
        if ( current_user_can( 'edit_posts' ) && current_user_can( 'edit_pages' ) && user_can_richedit() ) {
            add_filter( 'mce_buttons', array(__CLASS__, 'gicatalog_register_tinymce_button') );
            add_filter( 'mce_external_plugins', array(__CLASS__, 'gicatalog_add_tinymce_button') );
        }
    }
    
    public static function gicatalog_register_tinymce_button($buttons) {
        array_push( $buttons, "btn_gicatalog" );
        return $buttons;
    }
    
    public static function gicatalog_add_tinymce_button($plugin_array) {
        wp_enqueue_script('jquery-ui-dialog');
        wp_enqueue_script('gicatalog-angularjs', GICATALOG_URI . 'js/angular.min.js');
        wp_enqueue_script('gicatalog-angularjs-animate', GICATALOG_URI . 'js/angular-animate.min.js');
        wp_enqueue_script('gicatalog-angularjs-bindonce', GICATALOG_URI . 'js/angular-bindonce.min.js');
        //having conflict with underscore used by WP Media Library
        wp_enqueue_script('gicatalog-lodash', GICATALOG_URI . 'js/lodash.min.js');
        
        wp_enqueue_script('gicatalog-admin-app', GICATALOG_URI . 'includes/views/admin/js/app.js');
        
        wp_localize_script( 'gicatalog-admin-app', 'catalogData',
                ['URI' => GICATALOG_URI,
                'nonce' => GICATALOG_NONCE,
                'ajax_url' => admin_url( 'admin-ajax.php' )]);
        
        wp_enqueue_script('gicatalog-admin-controller-shortcode', GICATALOG_URI . 'includes/views/admin/js/controllers/shortcode.js');
        
        wp_enqueue_style('gicatalog-jquery-ui-css', GICATALOG_URI . 'css/smoothness/jquery-ui-1.10.4.custom.min.css');
        
        $plugin_array['gi_catalog'] = GICATALOG_URI . 'includes/views/admin/js/editor_plugin.js';
        return $plugin_array;
    }
    public static function gicatalog_shortcode_html() {
        
        $script = file_get_contents(GICATALOG_URI . 'includes/views/admin/templates/shortcode.html');
        echo $script;
    }
    
    public static function gicatalog_load_admin_actions() {
        add_action('wp_ajax_gicatalog_send_message', array(__CLASS__, 'gicatalog_send_message'));
        
        add_action('wp_ajax_gicatalog_get_group', array(__CLASS__, 'gicatalog_get_group'));
        add_action('wp_ajax_nopriv_gicatalog_get_group', array(__CLASS__, 'gicatalog_get_group'));
        add_action('wp_ajax_gicatalog_get_groups', array(__CLASS__, 'gicatalog_get_groups'));
        add_action('wp_ajax_gicatalog_add_group', array(__CLASS__, 'gicatalog_add_group'));
        add_action('wp_ajax_gicatalog_update_group', array(__CLASS__, 'gicatalog_update_group'));
        add_action('wp_ajax_gicatalog_delete_group', array(__CLASS__, 'gicatalog_delete_group'));

        add_action('wp_ajax_gicatalog_add_category', array(__CLASS__, 'gicatalog_add_category'));
        add_action('wp_ajax_gicatalog_update_category', array(__CLASS__, 'gicatalog_update_category'));
        add_action('wp_ajax_gicatalog_delete_category', array(__CLASS__, 'gicatalog_delete_category'));
        add_action('wp_ajax_gicatalog_save_category', array(__CLASS__, 'gicatalog_save_category'));
        add_action('wp_ajax_gicatalog_get_group_categories', array(__CLASS__, 'gicatalog_get_group_categories'));
        add_action('wp_ajax_gicatalog_get_categories', array(__CLASS__, 'gicatalog_get_categories'));
        add_action('wp_ajax_gicatalog_get_category', array(__CLASS__, 'gicatalog_get_category'));
        add_action('wp_ajax_nopriv_gicatalog_get_category', array(__CLASS__, 'gicatalog_get_category'));

        add_action('wp_ajax_gicatalog_richtext_shortcode', array(__CLASS__, 'gicatalog_richtext_shortcode'));
        add_shortcode('gicatalog_richtext', array(__CLASS__, 'gicatalog_richtext_shortcode_callback'));

        add_action('wp_ajax_gicatalog_add_tab', array(__CLASS__, 'gicatalog_add_tab'));
        add_action('wp_ajax_gicatalog_update_tab', array(__CLASS__, 'gicatalog_update_tab'));
        add_action('wp_ajax_gicatalog_remove_tab', array(__CLASS__, 'gicatalog_remove_tab'));
        
        add_action('wp_ajax_gicatalog_add_accordion', array(__CLASS__, 'gicatalog_add_accordion'));
        add_action('wp_ajax_gicatalog_update_accordion', array(__CLASS__, 'gicatalog_update_accordion'));
        add_action('wp_ajax_gicatalog_remove_accordion', array(__CLASS__, 'gicatalog_remove_accordion'));
        
        add_action('wp_ajax_gicatalog_save_settings', array(__CLASS__, 'gicatalog_save_settings'));
        
        add_action('wp_ajax_gicatalog_search', array(__CLASS__, 'gicatalog_search'));
        add_action('wp_ajax_nopriv_gicatalog_search', array(__CLASS__, 'gicatalog_search'));
        add_action('wp_ajax_gicatalog_send_share_email', array(__CLASS__, 'gicatalog_send_share_email'));
        add_action('wp_ajax_nopriv_gicatalog_send_share_email', array(__CLASS__, 'gicatalog_send_share_email'));
    }
    
    public function gicatalog_admin_menu() {
        $hook_catalog = add_options_page(__('GI-Catalog', 'menu-gicatalog'), __('GI-Catalog', 'menu-gicatalog'), 'manage_options', 'gi-catalog', array(__CLASS__, 'gicatalog_managecatalogs_page'));
        add_action('load-' . $hook_catalog, array(__CLASS__, 'init_managecatalog'));

        /* $hook_menus = add_submenu_page('gi-catalog', __('Manage Menus', 'menu-gicatalog-managemenus'), __('Manage Menus', 'menu-gicatalog-managemenus'), 'manage_options', 'gi-catalog', array($this, 'girestt_managemenus_page'));
          add_action('load-' . $hook_menus, array(&$this, 'init_managemenus'));
          $hook_plans = add_submenu_page('gi-catalog', __('Manage Plans', 'menu-gicatalog-manageplans'), __('Manage Plans', 'menu-gicatalog-manageplans'), 'manage_options', 'gicatalog-manageplans', array($this, 'gicatalog_manageplans_page'));
          add_action('load-' . $hook_plans, array(&$this, 'init_manageplans')); */
        //add_submenu_page('gi-lms', __('Dashboard', 'menu-gilms-dashboard'), __('Dashboard', 'menu-gilms-dashboard'), 'gilms-student', 'gi-lms-dashboard', array($this, 'gilms_dashboard_page'));
    }

    public static function init_managecatalog() {
        include_once GICATALOG_INCLUDES . 'admin/GI_Catalog_ManageCatalogs.php';

        self::$catalogs = new GI_Catalog_ManageCatalogs();
    }

    public static function gicatalog_managecatalogs_page() {
        if (!current_user_can('manage_options')) {
            wp_die(__('You do not have sufficient permissions to access this page.'));
        }
        
        echo '<div class="wrap">';
        self::$catalogs->gicatalog_managecatalogs_tabs();
        /* $this->print_metabox($this->overview->show_course_registration_stats(), "Course Registration Stats");

          echo '<br class="clear" />';
          echo '<div class="hr hr-32 hr-dotted"></div>';
          echo '<h2 id="students-list">Students List</h2>';
          if (isset($_REQUEST['orderby']) || isset($_REQUEST['filter-student']) || isset($_REQUEST['s'])
          || isset($_REQUEST['new-course']) || isset($_REQUEST['paged']) || isset($_REQUEST['course-update'])) {

          $scpath = GILMS_URI . 'js/jquery.scrollto.js';
          print<<<SCRIPT
          <script type="text/javascript" src="$scpath"></script>
          <script>
          jQuery(function($){
          $('body').scrollTo('#students-list');
          });
          </script>
          SCRIPT;
          }

          $this->overview->show_students_table(); */

        echo '<br class="clear" />';
        echo "</div>";
    }

    public static function set_html_content_type() {
        return 'text/html';
    }

    public static function gicatalog_get_groups() {
        if (!empty($_POST) && check_ajax_referer(GICATALOG_NONCE_NAME)) {
            $group = new GI_Catalog_Group();
            $category = new GI_Catalog_Category();
            $data = [
                'groups' => $group->get(),
                'categories' => $category->get_categories(true, $group->get()[0]['groupid'])
            ];
            /*if (is_wp_error($result)) {
                self::check_error($result);
                die(json_encode(['success' => false, 'message' => self::print_error(), 'data' => $data]));
            } else {*/
                die(json_encode(['success' => true, 'message' => self::print_success(__('Group(s) retrieved successfully.', 'gicatalog')), 'data' => $data]));
            //}
        }
    }
    
    public static function gicatalog_get_group() {
        if (!empty($_POST) && check_ajax_referer(GICATALOG_NONCE_NAME)) {
            $group = new GI_Catalog_Group();
            $category = new GI_Catalog_Category();
            $group = $group->get(false, $_POST['groupid']);
            $data = [
                'group' => $group,
                'categories' => (count($group)>0)?$category->get(false, null, $group[0]['groupid']):[]
            ];
            /*if (is_wp_error($result)) {
                self::check_error($result);
                die(json_encode(['success' => false, 'message' => self::print_error(), 'data' => $data]));
            } else {*/
                die(json_encode(['success' => true, 'message' => self::print_success(__('Group retrieved successfully.', 'gicatalog')), 'data' => $data]));
            //}
        }
    }
    
    public static function gicatalog_add_group() {
        if (!empty($_POST) && check_ajax_referer(GICATALOG_NONCE_NAME)) {
            $group = new GI_Catalog_Group();
            $result = $group->add($_POST['rows']);
            $category = new GI_Catalog_Category();
            $data = [
                'groups' => $group->get(),
                'categories' => $category->get(true, null, $group->get()[0]['groupid'])
            ];
            if (is_wp_error($result)) {
                self::check_error($result);
                die(json_encode(['success' => false, 'message' => self::print_error(), 'data' => $data]));
            } else {
                die(json_encode(['success' => true, 'message' => self::print_success(__('Group(s) added successfully.', 'gicatalog')), 'data' => $data]));
            }
        }
    }

    public static function gicatalog_update_group() {
        if (!empty($_POST) && check_ajax_referer(GICATALOG_NONCE_NAME)) {
            $group = new GI_Catalog_Group();
            $result = $group->update($_POST['rows']);
            
            $data = [
                'groups' => $group->get()
            ];

            if (is_wp_error($result)) {
                self::check_error($result);
                die(json_encode(['success' => false, 'message' => self::print_error(), 'data' => $data]));
            } else {
                die(json_encode(['success' => true, 'message' => self::print_success(__('Group(s) updated successfully.', 'gicatalog')), 'data' => $data]));
            }
        }
    }

    public static function gicatalog_delete_group() {
        if (!empty($_POST) && check_ajax_referer(GICATALOG_NONCE_NAME)) {
            $group = new GI_Catalog_Group();
            $result = $group->delete($_POST['ids']);
            $category = new GI_Catalog_Category();
            $data = [
                'groups' => $group->get(),
                'categories' => $category->get(true, null, $group->get()[0]['groupid'])
            ];
            if (is_wp_error($result)) {
                self::check_error($result);
                die(json_encode(['success' => false, 'message' => self::print_error(), 'data' => $data]));
            } else {
                die(json_encode(['success' => true, 'message' => self::print_success(__('Group(s) deleted successfully.', 'gicatalog')), 'data' => $data]));
            }
        }
    }

    public static function gicatalog_add_category() {
        if (!empty($_POST) && check_ajax_referer(GICATALOG_NONCE_NAME)) {
            $category = new GI_Catalog_Category();
            $result = $category->add($_POST['rows']);

            if (is_wp_error($result)) {
                self::check_error($result);
                die(json_encode(['success' => false, 'message' => self::print_error(), 'data' => $category->get(false, null, $_POST['groupid'])]));
            } else {
                die(json_encode(['success' => true, 'message' => self::print_success(__('Category(ies) added successfully.', 'gicatalog')), 'data' => $category->get(false, null, $_POST['groupid'])]));
            }
        }
    }

    public static function gicatalog_update_category() {
        if (!empty($_POST) && check_ajax_referer(GICATALOG_NONCE_NAME)) {
            $category = new GI_Catalog_Category();
            $result = $category->update($_POST['rows']);

            if (is_wp_error($result)) {
                self::check_error($result);
                die(json_encode(['success' => false, 'message' => self::print_error(), 'data' => $category->get(false, null, $_POST['groupid'])]));
            } else {
                die(json_encode(['success' => true, 'message' => self::print_success(__('Category updated successfully.', 'gicatalog')), 'data' => $category->get(false, null, $_POST['groupid'])]));
            }
        }
    }

    public static function gicatalog_delete_category() {
        if (!empty($_POST) && check_ajax_referer(GICATALOG_NONCE_NAME)) {
            $category = new GI_Catalog_Category();
            $result = $category->delete($_POST['ids']);

            if (is_wp_error($result)) {
                self::check_error($result);
                die(json_encode(['success' => false, 'message' => self::print_error(), 'data' => $category->get(false, null, $_POST['groupid'])]));
            } else {
                die(json_encode(['success' => true, 'message' => self::print_success(__('Category deleted successfully.', 'gicatalog')), 'data' => $category->get(false, null, $_POST['groupid'])]));
            }
        }
    }
    
    public static function gicatalog_save_category() {
        if (!empty($_POST) && check_ajax_referer(GICATALOG_NONCE_NAME)) {
            $category = new GI_Catalog_Category();
            $result = $category->save($_POST['data'], $_POST['categoryid']);

            if (is_wp_error($result)) {
                self::check_error($result);
                die(json_encode(['success' => false, 'message' => self::print_error(), 'data' => $category->get(false, null, $_POST['groupid'])]));
            } else {
                die(json_encode(['success' => true, 'message' => self::print_success(__('Category saved successfully.', 'gicatalog')), 'data' => $category->get(false, null, $_POST['groupid'])]));
            }
        }
    }
    //retrieve with subcategories
    public static function gicatalog_get_group_categories() {
        if (!empty($_POST) && check_ajax_referer(GICATALOG_NONCE_NAME)) {
            $category = new GI_Catalog_Category();
            die(json_encode(['success' => true, 'message' => self::print_success(__('Categories retrieved successfully.', 'gicatalog')), 'data' => $category->get(false, null, $_POST['groupid'])]));
        }
    }
    //retrieve single list categories
    public static function gicatalog_get_categories() {
        if (!empty($_POST) && check_ajax_referer(GICATALOG_NONCE_NAME)) {
            $category = new GI_Catalog_Category();
            die(json_encode(['success' => true, 'message' => self::print_success(__('Categories retrieved successfully.', 'gicatalog')), 'data' => $category->get_categories(true, $_POST['groupid'])]));
        }
    }
    
    public static function gicatalog_get_category() {
        if (!empty($_POST) && check_ajax_referer(GICATALOG_NONCE_NAME)) {
            $category = new GI_Catalog_Category();
            $category = $category->get_category($_POST['categoryid']);
            die(json_encode(['success' => true, 'message' => self::print_success(__('Category retrieved successfully.', 'gicatalog')), 'data' => (count($category)>0)?$category[0]:[]]));
        }
    }
    
    public static function gicatalog_richtext_shortcode() {
        if (!empty($_POST) && check_ajax_referer(GICATALOG_NONCE_NAME)) {
            $data = do_shortcode(stripslashes($_POST['content']));
            /* $data .= '<script src="/wp-admin/js/word-count.js" type="text/javascript"></script>
              <script src="/wp-admin/js/editor.js" type="text/javascript"></script>
              <script src="/wp-includes/js/quicktags.js" type="text/javascript"></script>
              <script src="/wp-includes/js/thickbox/thickbox.js" type="text/javascript"></script>
              <script src="/wp-admin/js/media-upload.js" type="text/javascript"></script>'; */
            
            die(json_encode(['success' => true, 'message' => '', 'data' => $data]));
        }
    }

    public static function gicatalog_richtext_shortcode_callback1($attr, $content) {
        global $wp_version;
		
		
        // vars
        $id = 'wysiwyg-' . $attr['id'] . '-' . uniqid();


        $output = '<div id="wp-' . $id . '-wrap" class="acf_wysiwyg wp-editor-wrap" data-toolbar="full" data-upload="yes">';
        if( user_can_richedit() ):
        
        $output .= '<div id="wp-' . $id . '-editor-tools" class="wp-editor-tools">
                        <div id="wp-' . $id . '-media-buttons" class="hide-if-no-js wp-media-buttons">';
        
        ob_start();
        do_action( 'media_buttons' );
        $output .= ob_get_contents();
        ob_end_clean();
        
        $output .= '    </div>
                    </div>';
                        
        endif;
        
        $output .= '<div id="wp-' . $id . '-editor-container" class="wp-editor-container">
                        <textarea id="' . $id . '" class="wp-editor-area" name="' . $id . '" >';

        if( user_can_richedit() )
        {
            ob_start();
            wp_richedit_pre( $attr['value'] );
            $output .= ob_get_contents();
            ob_end_clean();
        } 
        else
        {
            ob_start();
            wp_htmledit_pre( $attr['value'] );
            $output .= ob_get_contents();
            ob_end_clean();
        }

        $output .= '    </textarea>
                    </div>
                </div>';
        return $output;
    }
    public static function gicatalog_richtext_shortcode_callback($attr, $content) {
        $tinymce = "";
        if (user_can_richedit()) {

            ob_start();
            wp_editor($content, $attr['id'], [
                'editor_height' => 100,
                'dfw' => false,
                'drag_drop_upload' => true,
                'wpautop' => true,
                'tabfocus_elements' => 'insert-media-button,save-post',
                /*'tinymce' => array(
                    'mode' => 'none',
                    'resize' => false,
                    'add_unload_trigger' => false,
                )*/
            ]);
            $tinymce = ob_get_contents();
            /*$tinymce .= '<table id="post-status-info"><tbody><tr>
                                <td id="wp-word-count">Word count: <span class="word-count">0</span></td>
                                <td id="content-resize-handle" class="hide-if-no-js"><br /></td>
                        </tr></tbody></table>';*/
            ob_end_clean();
        }
        return $tinymce;
    }

    public static function gicatalog_add_tab() {
        if (!empty($_POST) && check_ajax_referer(GICATALOG_NONCE_NAME)) {
            $category = new GI_Catalog_Category();
            $result = $category->addTab($_POST['categoryid'], $_POST['rows']);

            if (is_wp_error($result)) {
                self::check_error($result);
                die(json_encode(['success' => false, 'message' => self::print_error(), 'data' => $category->get(false, null, $_POST['groupid'])]));
            } else {
                die(json_encode(['success' => true, 'message' => self::print_success(__('Tab(s) added successfully.', 'gicatalog')), 'data' => $category->get(false, null, $_POST['groupid'])]));
            }
        }
    }

    public static function gicatalog_update_tab() {
        if (!empty($_POST) && check_ajax_referer(GICATALOG_NONCE_NAME)) {
            $category = new GI_Catalog_Category();
            $result = $category->updateTab($_POST['categoryid'], $_POST['rows']);

            if (is_wp_error($result)) {
                self::check_error($result);
                die(json_encode(['success' => false, 'message' => self::print_error(), 'data' => $category->get(false, null, $_POST['groupid'])]));
            } else {
                die(json_encode(['success' => true, 'message' => self::print_success(__('Tab updated successfully.', 'gicatalog')), 'data' => $category->get(false, null, $_POST['groupid'])]));
            }
        }
    }

    public static function gicatalog_remove_tab() {
        if (!empty($_POST) && check_ajax_referer(GICATALOG_NONCE_NAME)) {
            $category = new GI_Catalog_Category();
            $result = $category->removeTab($_POST['categoryid'], $_POST['tabid']);

            if (is_wp_error($result)) {
                self::check_error($result);
                die(json_encode(['success' => false, 'message' => self::print_error(), 'data' => $category->get(false, null, $_POST['groupid'])]));
            } else {
                die(json_encode(['success' => true, 'message' => self::print_success(__('Tab removed successfully.', 'gicatalog')), 'data' => $category->get(false, null, $_POST['groupid'])]));
            }
        }
    }
    
    public static function gicatalog_add_accordion() {
        if (!empty($_POST) && check_ajax_referer(GICATALOG_NONCE_NAME)) {
            $category = new GI_Catalog_Category();
            $result = $category->addAccordion($_POST['categoryid'], $_POST['tabid'], $_POST['rows']);

            if (is_wp_error($result)) {
                self::check_error($result);
                die(json_encode(['success' => false, 'message' => self::print_error(), 'data' => $category->get(false, null, $_POST['groupid'])]));
            } else {
                die(json_encode(['success' => true, 'message' => self::print_success(__('Accordion(s) added successfully.', 'gicatalog')), 'data' => $category->get(false, null, $_POST['groupid'])]));
            }
        }
    }
    public static function gicatalog_update_accordion() {
        if (!empty($_POST) && check_ajax_referer(GICATALOG_NONCE_NAME)) {
            $category = new GI_Catalog_Category();
            $result = $category->updateAccordion($_POST['categoryid'], $_POST['tabid'], $_POST['rows']);

            if (is_wp_error($result)) {
                self::check_error($result);
                die(json_encode(['success' => false, 'message' => self::print_error(), 'data' => $category->get(false, null, $_POST['groupid'])]));
            } else {
                die(json_encode(['success' => true, 'message' => self::print_success(__('Accordion updated successfully.', 'gicatalog')), 'data' => $category->get(false, null, $_POST['groupid'])]));
            }
        }
    }
    public static function gicatalog_remove_accordion() {
        if (!empty($_POST) && check_ajax_referer(GICATALOG_NONCE_NAME)) {
            $category = new GI_Catalog_Category();
            $result = $category->removeAccordion($_POST['categoryid'], $_POST['tabid'], $_POST['accordionid']);

            if (is_wp_error($result)) {
                self::check_error($result);
                die(json_encode(['success' => false, 'message' => self::print_error(), 'data' => $category->get(false, null, $_POST['groupid'])]));
            } else {
                die(json_encode(['success' => true, 'message' => self::print_success(__('Accordion removed successfully.', 'gicatalog')), 'data' => $category->get(false, null, $_POST['groupid'])]));
            }
        }
    }
    
    public static function gicatalog_search() {
        if (!empty($_POST) && check_ajax_referer(GICATALOG_NONCE_NAME)) {
            $category = new GI_Catalog_Category();
            $result = $category->search($_POST['search'], $_POST['type'], $_POST['categoryid'], $_POST['groupid'], false);
            
            if (is_wp_error($result)) {
                self::check_error($result);
                die(json_encode(['success' => false, 'message' => self::print_error(), 'data' => []]));
            } else {
                die(json_encode(['success' => true, 'message' => self::print_success(__('Search data retrieved successfully.', 'gicatalog')), 'data' => $result]));
            }
        }
    }
    
    public static function gicatalog_send_message() {
        if (!empty($_POST) && check_ajax_referer(GICATALOG_NONCE_NAME)) {
            add_filter( 'wp_mail_content_type', array(__CLASS__, 'set_html_content_type') );
            $headers = 'From: ' . stripslashes(get_site_option("gicatalog_email_from")) . ' <' . get_site_option("gicatalog_email_address") . '>' . "\r\n";
            wp_mail('gicatalog-support@glareofislam.com', $_POST['message']['subject'], 'From Site: ' . get_site_option('siteurl') . "<br/><p>" . nl2br($_POST['message']['message']) . "</p>", $headers);
            remove_filter( 'wp_mail_content_type', array(__CLASS__, 'set_html_content_type'));
            die(json_encode(['success' => true, 'message' => self::print_success(__('Message sent successfully.', 'gicatalog')), 'data' => []]));
            
        }
    }
    
    public static function gicatalog_save_settings() {
        if (!empty($_POST) && check_ajax_referer(GICATALOG_NONCE_NAME)) {
            extract($_POST['setting']);
            update_site_option("gicatalog_disable_jqueryui_css", $disable_jqueryui_css);
            update_site_option("gicatalog_disable_bootstrap_css", $disable_bootstrap_css);
            update_site_option("gicatalog_fb_app_id", sanitize_text_field($fb_app_id));
            update_site_option("gicatalog_fb_media_type", sanitize_text_field($fb_media_type));
            update_site_option("gicatalog_fb_image", esc_url($fb_image));
			update_site_option("gicatalog_email_from", sanitize_text_field($email_from));
			update_site_option("gicatalog_email_address", sanitize_email($email_address));
            update_site_option("gicatalog_email_subject", sanitize_text_field($email_subject));
            update_site_option("gicatalog_email_template", wp_kses_post($email_template));
            die(json_encode(['success' => true, 'message' => self::print_success(__('Settings saved successfully.', 'gicatalog')), 'data' => []]));
        }
    }
    
    public static function gicatalog_send_share_email() {
        if (!empty($_POST) && check_ajax_referer(GICATALOG_NONCE_NAME)) {
            extract($_POST['message']);
            add_filter( 'wp_mail_content_type', array(__CLASS__, 'set_html_content_type') );
            $headers = 'From: ' . stripslashes(get_site_option("gicatalog_email_from")) . ' <' . get_site_option("gicatalog_email_address") . '>' . "\r\n";
            $message = stripslashes(get_site_option("gicatalog_email_template"));
            $message = str_replace('[HEADER]', stripslashes($header), $message);
            $message = str_replace('[CONTENT]', stripslashes($content), $message);
            wp_mail($to, get_site_option("gicatalog_email_subject"), $message, $headers);
            remove_filter( 'wp_mail_content_type', array(__CLASS__, 'set_html_content_type'));
            die(json_encode(['success' => true, 'message' => self::print_success(__('Email sent successfully.', 'gicatalog')), 'data' => []]));
            
        }
    }
}

?>
