<?php
/**
 * 
 *
 * @author Zishan J.
 */

defined('ABSPATH') OR exit;

class GI_Catalog_Shortcode {
    private static $default_options = [
        'id' => 0,
        'default' => 'false',
        'show_search_bar' => 'true',
        'show_pagination' => 'true',
        'items_per_page' => '5',
        'collapsible_accordion' => 'false',
        'hide_singletab_header' => 'false'
    ];
    
    function __construct() {
        global $post;
        
        add_shortcode('gi_catalog', [&$this, 'gicatalog_shortcode']);
        add_filter('wp_title', [&$this, 'gicatalog_page_title'], 10, 1);
        add_action('wp_head', [&$this, 'gicatalog_meta']);
        add_filter( 'wp_mail_content_type', [&$this, 'set_html_content_type'] );
        
        include_once(GICATALOG_INCLUDES . 'models/GI_Catalog_Category.php');
        include_once(GICATALOG_INCLUDES . 'models/GI_Catalog_Group.php');
    }
    
    public static function set_html_content_type() {
        return 'text/html';
    }
    
    public static function gicatalog_shortcode($atts, $content="") {
        global $post;
        
        $atts = shortcode_atts(self::$default_options, $atts);
        
        if ($atts['default'] !== 'true')
            return;
        
        if (isset($_GET['gicatalog-id']))
            $catid = intval($_GET['gicatalog-id']);
	else
            $catid = intval($atts['id']);
        
        if (!empty($_GET['gicatalog-item'])) {
            $catid = explode('-', $_GET['gicatalog-item'])[1];
            $itemid = $_GET['gicatalog-item'];
        }else{
            $itemid = "";
        }
        
        $gicat = new GI_Catalog_Category();
        $cats = $gicat->get_category($catid);
        $cats = (count($cats)>0)?$cats[0]:[];
        
        wp_enqueue_script('gicatalog-angularjs', GICATALOG_URI . 'js/angular.min.js');
        wp_enqueue_script('gicatalog-angularjs-animate', GICATALOG_URI . 'js/angular-animate.min.js');
        wp_enqueue_script('gicatalog-angularjs-bindonce', GICATALOG_URI . 'js/angular-bindonce.min.js');
        wp_enqueue_script('gicatalog-lodash', GICATALOG_URI . 'js/lodash.min.js');
        wp_enqueue_script('gicatalog-site-ngclip', GICATALOG_URI . 'includes/views/site/js/vendors/ng-clip.min.js');
        wp_enqueue_script('gicatalog-site-zeroclipboard', GICATALOG_URI . 'includes/views/site/js/vendors/ZeroClipboard.min.js');
        
        wp_enqueue_script('gicatalog-site-app', GICATALOG_URI . 'includes/views/site/js/app.js');
        wp_enqueue_script('gicatalog-site-app-catalog', GICATALOG_URI . 'includes/views/site/js/controllers/shortcode.js');
        wp_enqueue_script('gicatalog-site-app-comp-tab', GICATALOG_URI . 'includes/views/site/js/components/tab.js');
        wp_enqueue_script('gicatalog-site-app-comp-accordion', GICATALOG_URI . 'includes/views/site/js/components/accordion.js');
        
        wp_localize_script( 'gicatalog-site-app', 'catalogData',
                ['URI' => GICATALOG_URI,
                 'query_item_url' => add_query_arg('gicatalog-item', '', get_permalink($post->ID)),
                 'query_catalogid_url' => add_query_arg('gicatalog-id', '', get_permalink($post->ID)),
                 'nonce' => GICATALOG_NONCE,
                 'ajax_url' => admin_url( 'admin-ajax.php' ),
                 'fb_app_id' => get_site_option('gicatalog_fb_app_id'),
                 'catdata' => $cats,
                 'item_id' => $itemid,
                 'collapsible_accordion' => ($atts['collapsible_accordion']==='true'),
                 'hide_singletab_header' => ($atts['hide_singletab_header'] === 'true'),
                 'show_search_bar' => ($atts['show_search_bar']==='true'),
                 'show_pagination' => ($atts['show_pagination']==='true'),
                 'items_per_page' => (intval($atts['items_per_page'])>0)?intval($atts['items_per_page']):self::$default_options['items_per_page'],
                ]);
        
        wp_enqueue_script('jquery-ui-tabs');
        wp_enqueue_script('jquery-ui-accordion');
        
        if (get_site_option('gicatalog_disable_jqueryui_css')==='false') {
            wp_enqueue_style('gicatalog-jquery-ui-css', GICATALOG_URI . 'css/smoothness/jquery-ui-1.10.4.custom.min.css');
        }
        wp_enqueue_style('gicatalog-site-css', GICATALOG_URI . 'includes/views/site/css/site.css');
        if (get_site_option('gicatalog_disable_bootstrap_css')==='false') {
            wp_enqueue_style('gicatalog-site-bootstrap-css', GICATALOG_URI . 'includes/views/site/css/bootstrap/css/bootstrap.css');
            wp_enqueue_style('gicatalog-site-bootstrap-theme-css', GICATALOG_URI . 'includes/views/site/css/bootstrap/css/bootstrap-theme.min.css');
        }
        wp_enqueue_script('gicatalog-site-bootstrap', GICATALOG_URI . 'includes/views/site/js/vendors/bootstrap.min.js');
        
        $tpl = file_get_contents( GICATALOG_INCLUDES . "views/site/templates/main.html");
        
        return $tpl;
    }
    
    public static function gicatalog_page_title($title) {
        if (!empty($_GET['gicatalog-item'])) {
            if (count(explode('-', $_GET['gicatalog-item'])) == 4) {
                $gicat = new GI_Catalog_Category();
                $accordion = $gicat->get_accordion(explode('-', $_GET['gicatalog-item'])[1], explode('-', $_GET['gicatalog-item'])[2], explode('-', $_GET['gicatalog-item'])[3]);
                if (!empty($accordion)) {
                    $title .= " - " . stripslashes($accordion['accordionname']);
                }
            }
        }
        return $title;
    }
    
    public static function gicatalog_meta() {
        global $post;
        
        if (!empty($_GET['gicatalog-item'])) {
            if (count(explode('-', $_GET['gicatalog-item'])) == 4) {
                $gicat = new GI_Catalog_Category();
                $accordion = $gicat->get_accordion(explode('-', $_GET['gicatalog-item'])[1], explode('-', $_GET['gicatalog-item'])[2], explode('-', $_GET['gicatalog-item'])[3]);
                $output = "";
                if (!empty($accordion)) {
                    $output = '<meta property="fb:app_id" content="' . get_site_option('gicatalog_fb_app_id') . '">
                            <meta property="og:site_name" content="' . get_bloginfo() . '">
                            <meta property="og:type" content="' . get_site_option('gicatalog_fb_media_type') . '">
                            <meta property="og:image" content="' . get_site_option('gicatalog_fb_image') . '">
                            <meta property="og:title" content="' . htmlspecialchars(stripslashes($accordion['accordionname'])) . '">
                            <meta property="og:description" content="' . htmlspecialchars(strip_tags(stripslashes(nl2br($accordion['accordioncontent'])))) . '">
                            <meta property="og:url" content="' . add_query_arg('gicatalog-item', $_GET['gicatalog-item'], get_permalink($post->ID)) . '">';
                }
                echo $output;
            }
        }
        
    }
}

?>
