<?php
/**
 * 
 *
 * @author Zishan J.
 */
defined('ABSPATH') OR exit;

add_action('widgets_init', 'GI_Catalog_Widget::register_me');

class GI_Catalog_Widget extends WP_Widget {

    function __construct() {
        parent::__construct(
                __CLASS__, // Base ID
                __('GI-Catalog', 'gicatalog'), // Name
                ['description' => __('Display the widget with catalog selection on sidebar.', 'gicatalog')] // Args
        );
    }

    public function widget($args, $instance) {

        global $post;

        $currentcat = null;

        if (isset($_GET['gicatalog-id']))
            $currentcat = intval($_GET['gicatalog-id']);

        if (!empty($_GET['gicatalog-item']))
            $currentcat = explode('-', $_GET['gicatalog-item'])[1];


        $pattern = "\[(\[?)(gi\_catalog)\b([^\]\/]*(?:\/(?!\])[^\]\/]*)*?)(?:(\/)\]|\](?:([^\[]*+(?:\[(?!\/\2\])[^\[]*+)*+)\[\/\2\])?)(\]?)";
        //$pattern = get_shortcode_regex();
        if (preg_match_all('/' . $pattern . '/s', $post->post_content, $matches)) {
            $category = new GI_Catalog_Category();
            $group = new GI_Catalog_Group();
            $groups = [];
            $has_default = false;

            foreach ($matches[0] as $shortcode) {
                preg_match('/[ ]+id *= *["\']?([0-9]+)["\']+/i', $shortcode, $match);
                $id = $match[1];
                preg_match('/default *= *["\']?([true|false]+)["\']+/i', $shortcode, $match);
                $default = null;
                if (!empty($match)) {
                    if ($match[1] === "true") {
                        $default = $id;
                        $has_default = true;
                    }
                }

                if (!empty($id)) {
                    $cat = $category->get(false, $id, null);
                    if (count($cat) == 0) {
                        echo '';
                        break;
                    }

                    $tmp = $group->get(false, $cat[0]->groupid)[0];
                    if (!is_null($default)) {
                        $tmp['default'] = $default;
                    }
                    $tmp['categories'] = $category->get(false, null, $cat[0]->groupid);
                    $groups[] = $tmp;
                }
            }

            if ($has_default) {
                echo $args['before_widget'];

                if ( ! empty( $instance['title'] ) ) {
                    echo $args['before_title'] . apply_filters( 'widget_title', $instance['title'] ). $args['after_title'];
		}
                
                wp_enqueue_script('jquery-ui-position');
                wp_enqueue_script('gicatalog-jquery.menu', GICATALOG_URI . 'js/jquery.ui.menu.min.js');
                wp_enqueue_script('gicatalog-site-app-ctrl-widget', GICATALOG_URI . 'includes/views/site/js/controllers/widget.js');
                wp_enqueue_script('gicatalog-site-app-comp-menu', GICATALOG_URI . 'includes/views/site/js/components/menu.js');
                wp_enqueue_script('gicatalog-site-app-comp-widget', GICATALOG_URI . 'includes/views/site/js/components/widget.js');


                if (isset($currentcat)) {
                    $current_group_id = $category->get_category($currentcat);
                    $current_group_id = (count($current_group_id) > 0) ? $current_group_id[0]->groupid : "";
                } else {
                    $current_group_id = "";
                }

                wp_localize_script('gicatalog-site-app-ctrl-widget', 'widgetData', [
                    'groups' => $groups,
                    'current_group_id' => $current_group_id
                ]);
                $css = "";
                if (!empty($instance['css'])) {
                    $css = '<style type="text/css">' . $instance['css'] . "</style>";
                } else {
                    wp_enqueue_style('gicatalog-widget', GICATALOG_URI . 'includes/views/site/css/widget.css');
                }
                echo $css . '<div id="gicatalog-widget" ng-controller="Widget as widget">
                        <gi-widget widget-id="gicatalog-widget-accordion"></gi-widget>
                    </div>';

                echo $args['after_widget'];
            }
        }

        /* if (!empty($title)) {
          echo $args['before_title'] . $title . $args['after_title'];
          } */
    }

    public function form($instance) {
        if (isset($instance['title'])) {
            $title = $instance['title'];
        } else {
            $title = "";
        }
        if (isset($instance['css'])) {
            $css = $instance['css'];
        } else {
            $css = file_get_contents(GICATALOG_INCLUDES . "views/site/css/widget.css");
        }
        ?>
        <p>
            <label for="<?php echo $this->get_field_id('title'); ?>"><?php _e('Title:'); ?></label> 
            <input class="widefat" id="<?php echo $this->get_field_id('title'); ?>" name="<?php echo $this->get_field_name('title'); ?>" type="text" value="<?php echo esc_attr($title); ?>">
        </p>
        <p>
            <label for="<?php echo $this->get_field_id('css'); ?>"><?php _e('CSS:'); ?></label> 
            <textarea class="widefat" id="<?php echo $this->get_field_id('css'); ?>" name="<?php echo $this->get_field_name('css'); ?>" cols="20" rows="16"><?php echo esc_textarea($css); ?></textarea>
        </p>
        <?php
    }

    public function update($new_instance, $old_instance) {
        $instance = array();
        $instance['css'] = (!empty($new_instance['css']) ) ? strip_tags($new_instance['css']) : '';
        $instance['title'] = (!empty($new_instance['title']) ) ? strip_tags($new_instance['title']) : '';

        return $instance;
    }

    public static function register_me() {

        register_widget(__CLASS__);
    }

}
?>
