<?php
defined( 'ABSPATH' ) OR exit;
/**
 * Description of GI_Catalog_Category
 *
 * @author Zishan J.
 */
class GI_Catalog_Category {
    
    function __construct() {
        global $wpdb;
        
        $wpdb->hide_errors();
    }
    
    function add($rows) {
        global $wpdb;
        
        $error = null;
        
        foreach ($rows as $row) {
            if (trim($row['categoryname']) !== "") {
                $data = [
                    'groupid' => intval($row['groupid']),
                    'categoryname' => sanitize_text_field(trim($row['categoryname'])),
                    'categorycss' => sanitize_text_field(trim($row['categorycss'])),
                    'categorydirection' => sanitize_text_field(trim($row['categorydirection'])),
                    'categorysortorder' => intval($row['categorysortorder']),
                    'categorycreateddate' => date('Y-m-d H:i:s'),
                    'categorycontent' => maybe_serialize([
                        'showtabbedcontent' => 'false',
                        'content' => '',
                        'tabs' => []
                    ])
                ];
                if (isset($row['subcategoryid']))
                    $data['subcategoryid'] = intval($row['subcategoryid']);

                $result = $wpdb->insert(GICATALOG_TABLE_PREFIX . 'category', $data);
                if (!$result && !empty($wpdb->last_error))
                    $error[] = $wpdb->last_error;
            }
        }
        
        if ($error)
            return new WP_Error('categoryadd-error', __('An error occurred while creating new category(ies): ' . join(", ", $error) . '<br/>', 'gicatalog'));
        
        return true;
    }
    
    function update($rows) {
        global $wpdb;
        
        $error = null;
        
        foreach ($rows as $row) {
            if (trim($row['categoryname']) !== "") {
                $data = [
                    'categoryname' => sanitize_text_field(trim($row['categoryname'])),
                    'categorycss' => sanitize_text_field(trim($row['categorycss'])),
                    'categorydirection' => sanitize_text_field(trim($row['categorydirection'])),
                    'categorysortorder' => intval($row['categorysortorder'])
                ];
                $categoryid = intval($row['categoryid']);
                $result = $wpdb->update(GICATALOG_TABLE_PREFIX . 'category', $data, array('categoryid' => $categoryid), null, array('%d'));
                if (!$result && !empty($wpdb->last_error))
                    $error[] = $wpdb->last_error;
            }
        }
        
        if ($error)
            return new WP_Error('categoryupdate-error', __('An error occurred while updating category: ' . join(", ", $error) . '<br/>', 'gicatalog'));
        
        return true;
        
    }
    
    function save($data, $categoryid) {
        global $wpdb;
        
        $error = null;
        $tabs = [];
        
        $data['content'] = wp_kses_post($data['content']);
        
        if (isset($data['tabs']))
            $tabs = is_array($data['tabs'])?$data['tabs']:[];
        
        foreach ($tabs as $key => $tab) {
            $tabs[$key]['id'] = $key;
            $tabs[$key]['tabname'] = sanitize_text_field($tab['tabname']);
            $tabs[$key]['tabcss'] = sanitize_text_field($tab['tabcss']);
            $tabs[$key]['tabdirection'] = sanitize_text_field($tab['tabdirection']);
            $tabs[$key]['tabcontent'] = wp_kses_post($tab['tabcontent']);
            
            if (isset($tabs[$key]['accordions'])) {
                foreach ($tabs[$key]['accordions'] as $key1 => $accordion) {
                    $tabs[$key]['accordions'][$key1]['accordionname'] = sanitize_text_field($accordion['accordionname']);
                    $tabs[$key]['accordions'][$key1]['accordioncss'] = sanitize_text_field($accordion['accordioncss']);
                    $tabs[$key]['accordions'][$key1]['accordiondirection'] = sanitize_text_field($accordion['accordiondirection']);
                    $tabs[$key]['accordions'][$key1]['accordioncontent'] = wp_kses_post($accordion['accordioncontent']);
                }
            }
        }
        
        $data['tabs'] = $tabs;
        
        $data = [
            'categorycontent' => maybe_serialize($data)
        ];
        
        $result = $wpdb->update(GICATALOG_TABLE_PREFIX . 'category', $data, array('categoryid' => $categoryid), null, array('%d'));
        
        if (!$result && !empty($wpdb->last_error))
            $error[] = $wpdb->last_error;

        if ($error)
            return new WP_Error('categorysave-error', __('An error occurred while saving category: ' . join(", ", $error) . '<br/>', 'gicatalog'));
        
        return true;
        
    }
    
    function delete($ids) {
        global $wpdb;
        
        $error = null;
        
        $result = $wpdb->query("DELETE FROM " . GICATALOG_TABLE_PREFIX . "category WHERE categoryid IN ({$ids})");
        
        if (!$result)
            return new WP_Error('categoryupdate-error', __('An error occurred while deleting category: ' . $wpdb->last_error . '<br/>', 'gicatalog'));
        
        return true;
    }
    
    function addTab($catid, $tabs) {
        global $wpdb;
        
        $error = null;
        $catcontent = "";
        $cattabs = [];
        
        $row = $wpdb->get_row( $wpdb->prepare( "SELECT categorycontent FROM " . GICATALOG_TABLE_PREFIX . "category WHERE categoryid=%d", $catid ) );
        if (is_object($row)) {
            $catcontents = maybe_unserialize($row->categorycontent);
            if(is_array($catcontents)) {
                $catcontent = $catcontents['content'];
                $cattabs = $catcontents['tabs'];
            }
        }
        $id = count($cattabs);
        foreach ($tabs as $key => $tab) {
            $tabs[$key]['id'] = $id;
            $tabs[$key]['tabname'] = sanitize_text_field($tab['tabname']);
            $tabs[$key]['tabcss'] = sanitize_text_field($tab['tabcss']);
            $tabs[$key]['tabdirection'] = sanitize_text_field($tab['tabdirection']);
            $tabs[$key]['tabcontent'] = wp_kses_post($tab['tabcontent']);
            $tabs[$key]['tabcreateddate'] = date('Y-m-d H:i:s');
            $tabs[$key]['accordions'] = [];
            $id++;
        }
        
        $cattabs = array_merge($cattabs, $tabs);
        
        $data = [
            'categorycontent' => maybe_serialize([
                'showtabbedcontent' => 'true',
                'content' => $catcontent,
                'tabs' => $cattabs
            ])
        ];
        
        $result = $wpdb->update(GICATALOG_TABLE_PREFIX . 'category', $data, array('categoryid' => $catid), null, array('%d'));
        if (!$result && !empty($wpdb->last_error))
            $error[] = $wpdb->last_error;

        
        if ($error)
            return new WP_Error('tabadd-error', __('An error occurred while adding tab(s): ' . join(", ", $error) . '<br/>', 'gicatalog'));
        
        return true;
        
    }
    
    function updateTab($catid, $tabs) {
        global $wpdb;
        
        $error = null;
        $catcontent = "";
        $cattabs = [];
        
        foreach ($tabs as $key => $tab) {
            //$tabs[$key]['id'] = $key;
            $tabs[$key]['tabname'] = sanitize_text_field($tab['tabname']);
            $tabs[$key]['tabcss'] = sanitize_text_field($tab['tabcss']);
            $tabs[$key]['tabdirection'] = sanitize_text_field($tab['tabdirection']);
            $tabs[$key]['tabcontent'] = wp_kses_post($tab['tabcontent']);
            $tabs[$key]['tabupdateddate'] = date('Y-m-d H:i:s');
        }
        
        $row = $wpdb->get_row( $wpdb->prepare( "SELECT categorycontent FROM " . GICATALOG_TABLE_PREFIX . "category WHERE categoryid=%d", $catid ) );
        if (is_object($row)) {
            $catcontents = maybe_unserialize($row->categorycontent);
            if(is_array($catcontents)) {
                $catcontent = $catcontents['content'];
                $cattabs = $catcontents['tabs'];
            }
        }
        foreach($cattabs as $key => $tab) {
            if($tab["id"] == $tabs[0]['id']) {
                $cattabs[$key] = $tabs[0];
                break;
            }
        }
        
        $data = [
            'categorycontent' => maybe_serialize([
                'showtabbedcontent' => 'true',
                'content' => $catcontent,
                'tabs' => $cattabs
            ])
        ];
        
        $result = $wpdb->update(GICATALOG_TABLE_PREFIX . 'category', $data, array('categoryid' => $catid), null, array('%d'));
        if (!$result && !empty($wpdb->last_error))
            $error[] = $wpdb->last_error;

        
        if ($error)
            return new WP_Error('tabadd-error', __('An error occurred while updating tab(s): ' . join(", ", $error) . '<br/>', 'gicatalog'));
        
        return true;
        
    }
    
    function removeTab($categoryid, $tabid) {
        global $wpdb;
        
        $error = null;
        $catcontent = "";
        $cattabs = [];
        
        $row = $wpdb->get_row( $wpdb->prepare( "SELECT categorycontent FROM " . GICATALOG_TABLE_PREFIX . "category WHERE categoryid=%d", $categoryid ) );
        if (is_object($row)) {
            $catcontents = maybe_unserialize($row->categorycontent);
            if(is_array($catcontents)) {
                $showtabbedcontent = $catcontents['showtabbedcontent'];
                $catcontent = $catcontents['content'];
                $cattabs = $catcontents['tabs'];
            }
        }
        foreach($cattabs as $key => $tab) {
            if($tab["id"] == $tabid) {
                array_splice($cattabs, $key, 1);
                break;
            }
        }
        
        $data = [
            'categorycontent' => maybe_serialize([
                'showtabbedcontent' => $showtabbedcontent,
                'content' => $catcontent,
                'tabs' => $cattabs
            ])
        ];
        
        $result = $wpdb->update(GICATALOG_TABLE_PREFIX . 'category', $data, array('categoryid' => $categoryid), null, array('%d'));
        if (!$result && !empty($wpdb->last_error))
            $error[] = $wpdb->last_error;

        if ($error)
            return new WP_Error('tabadd-error', __('An error occurred while removing tab: ' . join(", ", $error) . '<br/>', 'gicatalog'));
        
        return true;
        
    }
    
    function addAccordion($catid, $tabid, $accordions) {
        global $wpdb;
        
        $error = null;
        $catcontent = "";
        $cattabs = [];
        
        $row = $wpdb->get_row( $wpdb->prepare( "SELECT categorycontent FROM " . GICATALOG_TABLE_PREFIX . "category WHERE categoryid=%d", $catid ) );
        if (is_object($row)) {
            $catcontents = maybe_unserialize($row->categorycontent);
            if(is_array($catcontents)) {
                $showtabbedcontent = $catcontents['showtabbedcontent'];
                $catcontent = $catcontents['content'];
                $cattabs = $catcontents['tabs'];
            }
        }
        foreach($cattabs as $key => $tab) {
            if($tab["id"] == $tabid) {
                $cattabaccordions = isset($cattabs[$key]['accordions'])?$cattabs[$key]['accordions']:[];
                $id = empty($cattabaccordions)?0:count($cattabaccordions);
                foreach ($accordions as $key1 => $tab) {
                    $accordions[$key1]['id'] = $id;
                    $accordions[$key1]['accordionname'] = sanitize_text_field($tab['accordionname']);
                    $accordions[$key1]['accordioncss'] = sanitize_text_field($tab['accordioncss']);
                    $accordions[$key1]['accordiondirection'] = sanitize_text_field($tab['accordiondirection']);
                    $accordions[$key1]['accordioncontent'] = wp_kses_post($tab['accordioncontent']);
                    $accordions[$key1]['accordioncreateddate'] = date('Y-m-d H:i:s');
                    $id++;
                }
                $cattabs[$key]['showaccordioncontent'] = 'true';
                $cattabs[$key]['accordions'] = array_merge($cattabaccordions, $accordions);
                
                break;
            }
        }
        
        $data = [
            'categorycontent' => maybe_serialize([
                'showtabbedcontent' => $showtabbedcontent,
                'content' => $catcontent,
                'tabs' => $cattabs
            ])
        ];
        
        $result = $wpdb->update(GICATALOG_TABLE_PREFIX . 'category', $data, array('categoryid' => $catid), null, array('%d'));
        if (!$result && !empty($wpdb->last_error))
            $error[] = $wpdb->last_error;

        
        if ($error)
            return new WP_Error('tabadd-error', __('An error occurred while updating accordion(s): ' . join(", ", $error) . '<br/>', 'gicatalog'));
        
        return true;
        
    }
    
    function updateAccordion($catid, $tabid, $accordions) {
        global $wpdb;
        
        $error = null;
        $catcontent = "";
        $cattabs = [];
        
        foreach ($accordions as $key => $accordion) {
            $accordions[$key]['accordionname'] = sanitize_text_field($accordion['accordionname']);
            $accordions[$key]['accordioncss'] = sanitize_text_field($accordion['accordioncss']);
            $accordions[$key]['accordiondirection'] = sanitize_text_field($accordion['accordiondirection']);
            $accordions[$key]['accordioncontent'] = wp_kses_post($accordion['accordioncontent']);
            $accordions[$key]['accordionupdateddate'] = date('Y-m-d H:i:s');
        }
        
        $row = $wpdb->get_row( $wpdb->prepare( "SELECT categorycontent FROM " . GICATALOG_TABLE_PREFIX . "category WHERE categoryid=%d", $catid ) );
        if (is_object($row)) {
            $catcontents = maybe_unserialize($row->categorycontent);
            if(is_array($catcontents)) {
                $showtabbedcontent = $catcontents['showtabbedcontent'];
                $catcontent = $catcontents['content'];
                $cattabs = $catcontents['tabs'];
            }
        }
        foreach($cattabs as $key => $tab) {
            if($tab["id"] == $tabid) {
                $cattabaccordions =& $cattabs[$key]['accordions'];
                foreach ($cattabaccordions as $key1 => $accordion) {
                    if ($accordion['id'] == $accordions[0]['id']) {
                        $cattabaccordions[$key1] = $accordions[0];
                        break;
                    }
                }
                break;
            }
        }
        
        $data = [
            'categorycontent' => maybe_serialize([
                'showtabbedcontent' => $showtabbedcontent,
                'content' => $catcontent,
                'tabs' => $cattabs
            ])
        ];
        
        $result = $wpdb->update(GICATALOG_TABLE_PREFIX . 'category', $data, array('categoryid' => $catid), null, array('%d'));
        if (!$result && !empty($wpdb->last_error))
            $error[] = $wpdb->last_error;

        
        if ($error)
            return new WP_Error('tabadd-error', __('An error occurred while updating accordion: ' . join(", ", $error) . '<br/>', 'gicatalog'));
        
        return true;
        
    }
    
    function removeAccordion($categoryid, $tabid, $accordionid) {
        global $wpdb;
        
        $error = null;
        $catcontent = "";
        $cattabs = [];
        
        $row = $wpdb->get_row( $wpdb->prepare( "SELECT categorycontent FROM " . GICATALOG_TABLE_PREFIX . "category WHERE categoryid=%d", $categoryid ) );
        if (is_object($row)) {
            $catcontents = maybe_unserialize($row->categorycontent);
            if(is_array($catcontents)) {
                $showtabbedcontent = $catcontents['showtabbedcontent'];
                $catcontent = $catcontents['content'];
                $cattabs = $catcontents['tabs'];
            }
        }
        foreach($cattabs as $key => $tab) {
            if($tab["id"] == $tabid) {
                $cattabaccordions =& $cattabs[$key]['accordions'];
                foreach ($cattabaccordions as $key1 => $accordion) {
                    if ($accordion['id'] == $accordionid) {
                        array_splice($cattabaccordions, $key1, 1);
                        break;
                    }
                }
                break;
            }
        }
        
        $data = [
            'categorycontent' => maybe_serialize([
                'showtabbedcontent' => $showtabbedcontent,
                'content' => $catcontent,
                'tabs' => $cattabs
            ])
        ];
        
        $result = $wpdb->update(GICATALOG_TABLE_PREFIX . 'category', $data, array('categoryid' => $categoryid), null, array('%d'));
        if (!$result && !empty($wpdb->last_error))
            $error[] = $wpdb->last_error;

        if ($error)
            return new WP_Error('tabadd-error', __('An error occurred while removing accordion: ' . join(", ", $error) . '<br/>', 'gicatalog'));
        
        return true;
        
    }
    
    function search($search, $type, $categoryid, $groupid, $sortbyname=true) {
        global $wpdb;
        
        $error = null;
        $sortby = (!$sortbyname) ? "categorysortorder ASC" : "categoryname ASC";
        if ($type === 'category') {
            $where = "categoryid = " . intval($categoryid);
        }elseif ($type === 'group') {
            $where = "groupid = " . intval($groupid);
        }
        
        $search1 = explode(' ', $search);
        $tmp = [];
        foreach($search1 as $src) {
            $tmp[] = "categorycontent LIKE '%" . $src . "%'";
        }
        $search1 = implode(" OR ", $tmp);
        
        $result = $wpdb->get_results("SELECT * FROM " . GICATALOG_TABLE_PREFIX . "category WHERE " . $where . " AND (" . $search1 . ")  ORDER BY " . $sortby);
        
        if (!$result && !empty($wpdb->last_error))
            $error[] = $wpdb->last_error;

        if ($error)
            return new WP_Error('search-error', __('An error occurred while searching: ' . join(", ", $error) . '<br/>', 'gicatalog'));
        
        $tmp = null;
        $search1 = explode(' ', $search);
        foreach ($result as $cat) {
            $cat->categorycontent = maybe_unserialize($cat->categorycontent);
            if (isset($cat->categorycontent['tabs'])) {
                foreach ($cat->categorycontent['tabs'] as $tab) {
                    if (isset($tab['accordions'])) {
                        foreach($tab['accordions'] as $accordion) {
                            $found = false;
                            foreach($search1 as $src) {
                                if (strpos($accordion['accordionname'], $src) !== false || strpos($accordion['accordioncontent'], $src) !== false && $tab['showaccordioncontent'] === 'true')
                                    $found = true;
                            }
                            if ($found) {
								$accordion['itemid'] = $cat->groupid . '-' . $cat->categoryid . '-' . $tab['id'] . '-' . $accordion['id'];
                                $accordion['showaccordioncontent'] = 'true';
                                $accordion['showlinkicon'] = $tab['showlinkicon'];
                                $accordion['showemailicon'] = $tab['showemailicon'];
                                $accordion['showshareicon'] = $tab['showshareicon'];
                                $tmp[] = $accordion;
                            }
                        }
                    }
                }
            }
        }
        $accord = null;
        if (is_array($tmp)){
            $accord['accordions'] = $tmp;
        }
        return $accord;
    }
    
    function get_categories($sortbyname=true, $groupid=NULL) {
        global $wpdb;
        
        $error = null;
        $sortby = (!$sortbyname) ? "categorysortorder ASC" : "categoryname ASC";
        $groupid = (is_null($groupid))?0:$groupid;
        $where = (!is_array($groupid)?("groupid" . (($groupid==0)?">0":"=".$groupid)):("groupid IN (" . join(",", $groupid) . ")"));
        
        $result = $wpdb->get_results("SELECT * FROM " . GICATALOG_TABLE_PREFIX . "category WHERE " . $where . " ORDER BY " . $sortby);
        
        if (!$result && !empty($wpdb->last_error))
            $error[] = $wpdb->last_error;

        if ($error)
            return new WP_Error('search-error', __('An error occurred while searching: ' . join(", ", $error) . '<br/>', 'gicatalog'));
        
        foreach ($result as $cat) {
            $cat->categorycontent = maybe_unserialize($cat->categorycontent);
        }
        
        return $result;
    }
    
    private function process_audio_shortcode($content) {
        $pattern = "\[(\[?)(audio)\b([^\]\/]*(?:\/(?!\])[^\]\/]*)*?)(?:(\/)\]|\](?:([^\[]*+(?:\[(?!\/\2\])[^\[]*+)*+)\[\/\2\])?)(\]?)";
        
        return preg_replace_callback('/' . $pattern . '/s', function($matches) {
            
            preg_match('/[ ]+src *= *["\']?(.*)["\']+/i', $matches[0], $match);
            $src = stripslashes($match[1]);
            if (!empty($src)) {
                return wp_audio_shortcode([
                    'src' => $src
                ]);
            }
            
        }, $content);
    }
    
    function get_category($id) {
        global $wpdb;
        $error = null;
        
        $result = $wpdb->get_results("SELECT * FROM " . GICATALOG_TABLE_PREFIX . "category WHERE categoryid = " . intval($id));
        
        if (!$result && !empty($wpdb->last_error))
            $error[] = $wpdb->last_error;

        if ($error)
            return new WP_Error('search-error', __('An error occurred while retrieving category: ' . join(", ", $error) . '<br/>', 'gicatalog'));
        
        foreach ($result as $cat) {
            $cat->categorycontent = maybe_unserialize($cat->categorycontent);
            $cat->categorycontent['content'] = $this->process_audio_shortcode($cat->categorycontent['content']);
            if (isset($cat->categorycontent['tabs'])) {
                foreach ($cat->categorycontent['tabs'] as $tabid => $tab) {
                    $cat->categorycontent['tabs'][$tabid]['tabcontent'] = $this->process_audio_shortcode($tab['tabcontent']);
                    if (isset($tab['accordions'])) {
                        foreach($tab['accordions'] as $accordionid => $accordion) {
                            $cat->categorycontent['tabs'][$tabid]['accordions'][$accordionid]['accordioncontent'] = $this->process_audio_shortcode($accordion['accordioncontent']);
                        }
                    }
                }
            }
        }
        
        return $result;
    }
    
    function get_accordion($category_id, $tab_id, $accordion_id) {
        $cat = $this->get_category($category_id);
        $cat = (count($cat)>0)?$cat[0]:[];
        $data = [];
        if (isset($cat->categorycontent['tabs'])) {
            foreach ($cat->categorycontent['tabs'] as $tabid => $tab) {
                if ($tabid == intval($tab_id)) {
                    if (isset($tab['accordions'])) {
                        foreach($tab['accordions'] as $accordionid => $accordion) {
                            if ($accordionid == intval($accordion_id)) {
                                $data = $accordion;
                                break 2;
                            }
                        }
                    }
                }
            }
        }
        return $data;
    }
    
    function get($sortbyname=true, $id=NULL, $groupid=NULL) {
        global $wpdb;
        
        $sortby = (!$sortbyname) ? "categorysortorder ASC" : "categoryname ASC";
        if (is_null($groupid)) {
            $id = (is_null($id))?0:$id;
            $where = (!is_array($id)?("categoryid".(($id==0)?">0":"=".$id)):("categoryid IN (" . join(",", $id) . ")"));
        } else {
            $groupid = (is_null($groupid))?0:$groupid;
            $where = (!is_array($groupid)?("groupid" . (($groupid==0)?">0":"=".$groupid)):("groupid IN (" . join(",", $groupid) . ")"));
        }
        $result = $wpdb->get_results("SELECT * FROM " . GICATALOG_TABLE_PREFIX . "category WHERE " . $where . " AND (subcategoryid IS NOT NULL OR subcategoryid > 0)  ORDER BY " . $sortby);
        foreach ($result as $cat) {
            $cat->categorycontent = maybe_unserialize($cat->categorycontent);
        }
        
        $data = null;
        
        /*foreach ($result as $category) {
            $data[] = [
                'categoryid'=>$category->categoryid, 
                'name'=>$category->categoryname,
                'css'=>$category->categorycss,
                'direction'=>$category->categorydirection,
                'subcategoryid'=>$category->subcategoryid];
        }*/
        
        /*function category($cat1) {
            return (is_null($cat1->subcategoryid));
        }
        $categories = array_filter($result, 'category');
        function subcategory($cat1) {
            return (!is_null($cat1->subcategoryid));
        }
        $subcategories = array_filter($result, 'subcategory');*/
        /*$categories = $result;
        foreach ($categories as $category) {
            $result = $wpdb->get_results("SELECT * FROM " . GICATALOG_TABLE_PREFIX . "category WHERE subcategoryid = " . $category->categoryid . "  ORDER BY " . $sortby);
            $category->subcategory = $result;
            foreach ($subcategories as $subcategory) {
                if ($category->categoryid == $subcategory->subcategoryid) {
                    $category->subcategory[] = $subcategory;
                }
            }
        }*/
        
        $subcategories = array();
        foreach ($result as $subcat) {
          $id = $subcat->subcategoryid;
          if (isset($subcategories[$id])) {
             $subcategories[$id][] = $subcat;
          } else {
             $subcategories[$id] = array($subcat);
          }
        }
        
        $categories = $wpdb->get_results("SELECT * FROM " . GICATALOG_TABLE_PREFIX . "category WHERE " . $where . " AND (subcategoryid IS NULL OR subcategoryid = 0)  ORDER BY " . $sortby);
        foreach ($categories as $cat) {
            $cat->categorycontent = maybe_unserialize($cat->categorycontent);
        }
        
        if (count($categories)==0)
            return [];
        
        if (!function_exists('findCat')):
        function findCat(&$categories, &$subcategories, $id, $val) {
            foreach ($categories as $cat) {
                if ($cat->categoryid == $id) {
                    $cat->subcategory = $val;
                    unset($subcategories[$id]);
                    break;
                }
                if (isset($cat->subcategory)) {
                    findCat($cat->subcategory, $subcategories, $id, $val);
                    break;
                }
            }
        }
        endif;
        while(count($subcategories)>0) {
            foreach($subcategories as $id=>$val) {
                findCat($categories, $subcategories, $id, $val);
            }
        }
            
        return $categories;
    }
}

?>
