<?php
defined( 'ABSPATH' ) OR exit;
/**
 * Description of GI_Catalog_Group
 *
 * @author Zishan J.
 */
class GI_Catalog_Group {
    
    function __construct() {
        global $wpdb;
        
        $wpdb->hide_errors();
    }
    
    function add($rows) {
        global $wpdb;
        
        $error = null;
        
        foreach ($rows as $row) {
            if (trim($row['name']) !== "") {
                $data = [
                    'groupname' => sanitize_text_field(trim($row['name'])),
                    'groupcss' => sanitize_text_field(trim($row['css'])),
                    'groupdirection' => sanitize_text_field(trim($row['direction'])),
                    'groupcreateddate' => date('Y-m-d H:i:s')
                ];

                $result = $wpdb->insert(GICATALOG_TABLE_PREFIX . 'group', $data);
                if (!$result && !empty($wpdb->last_error))
                    $error[] = $wpdb->last_error;
            }
        }
        
        if ($error)
            return new WP_Error('groupinsert-error', __('An error occurred while creating new group(s): ' . join(", ", $error) . '<br/>', 'gicatalog'));
        
        return true;
    }
    
    function update($rows) {
        global $wpdb;
        
        $error = null;
        
        foreach ($rows as $row) {
            if (trim($row['name']) !== "") {
                $data = [
                    'groupname' => sanitize_text_field(trim($row['name'])),
                    'groupcss' => sanitize_text_field(trim($row['css'])),
                    'groupdirection' => sanitize_text_field(trim($row['direction']))
                ];
                $groupid = intval($row['groupid']);
                $result = $wpdb->update(GICATALOG_TABLE_PREFIX . 'group', $data, array('groupid' => $groupid), null, array('%d'));
                if (!$result && !empty($wpdb->last_error))
                    $error[] = $wpdb->last_error;
            }
        }
        
        if ($error)
            return new WP_Error('groupupdate-error', __('An error occurred while updating group(s): ' . join(", ", $error) . '<br/>', 'gicatalog'));
        
        return true;
        
    }
    
    function delete($ids) {
        global $wpdb;
        
        $error = null;
        
        $result = $wpdb->query("DELETE FROM " . GICATALOG_TABLE_PREFIX . "group WHERE groupid IN ({$ids})");
        
        if (!$result && !empty($wpdb->last_error))
            return new WP_Error('groupupdate-error', __('An error occurred while deleting group(s): ' . $wpdb->last_error . '<br/>', 'gicatalog'));
        
        return true;
    }
    
    function get($sortbyname=true, $id=NULL) {
        global $wpdb;
        
        $sortby = (!$sortbyname) ? "groupcreateddate DESC" : "groupname ASC";
        $where = "";
        if (!is_null($id)) {
            $where = (!is_array($id)?("groupid=".$id):("groupid IN (" . join(",", $id) . ")"));
            $where = 'WHERE ' . $where;
        }
        
        $result = $wpdb->get_results("SELECT * FROM " . GICATALOG_TABLE_PREFIX . "group " . $where . " ORDER BY " . $sortby);
        
        $data = null;
        
        foreach ($result as $group) {
            $data[] = [
                'groupid'=>$group->groupid, 
                'name'=>$group->groupname,
                'css'=>$group->groupcss,
                'direction'=>$group->groupdirection];
            
        }
        return $data;
    }
}

?>
