'use strict';

catalog.controller('Groups', function($rootScope, $timeout, $http) {
    this.rows = [{id: 1, name: '', css: '', direction: 'ltr'}];
    this.data = groupData.groups;
    this.group = [];
    this.isEditMode = false;
    
    var self = this;
        
    this.insertRow = function insertRow() {
        var newid = (self.rows.length > 0) ? self.rows[self.rows.length - 1].id + 1 : 1;
        self.rows.push({id: newid, name: '', css: '', direction: 'ltr'});
        
    };
    this.removeRow = function removeRow(id) {
        ld.remove(self.rows, function(row) {
            return row.id == id;
        });
        /*var i = 1;
        var tmpRows = angular.copy(self.rows);
        angular.forEach(tmpRows, function(row) {
            row.id = i;
            i++;
        });
        $timeout(function(){
            self.rows = angular.copy(tmpRows);
            tmpRows = null;
        });*/
    };
    this.update = function update() {
        jQuery('#categories-message').html("").hide();
        
        var tmpRows = angular.copy(self.rows);
        ld.remove(tmpRows, function(row){
            return (ld.isEmpty(ld.trim(row.name)));
        });
        if (tmpRows.length == 0) {
            return false;
        }
        
        if (self.isEditMode) {
            jQuery.showStatusDialog({'message': 'Updating group(s)&hellip;'});
        }else{
            jQuery.showStatusDialog({'message': 'Adding group(s)&hellip;'});
        }
        
        var data = {
            action: (self.isEditMode)?'gicatalog_update_group':'gicatalog_add_group',
            rows: tmpRows,
            _ajax_nonce: groupData.nonce
        };

        $http.post(ajaxurl, jQuery.param(data)).then(function(response) {
            var tmpData = response.data;
            if (response.data.success){
                self.cancel();
                self.data = tmpData.data.groups;
                $rootScope.$broadcast('group.updated', tmpData.data);
            }else{

            }
            
            jQuery('#categories-message').html(tmpData.message).show();
            jQuery.showStatusDialog({show: false});
            jQuery.scrollTo('#categories-message', 800, {offset: -35});
        }, function(rejectReason) {
            console.log("request error");
            console.dir(rejectReason);
        });
        
    };
    
    this.grpDelete = function grpDelete() {
        jQuery('#categories-message').html("").hide();
        
        if (self.group.length == 0) {
            return false;
        }
        jQuery.showStatusDialog({message: 'Deleting group(s)&hellip;'});
        
        var data = {
            action: 'gicatalog_delete_group',
            ids: ld.pluck(self.group, 'groupid').join(","),
            _ajax_nonce: groupData.nonce
        };

        $http.post(ajaxurl, jQuery.param(data)).then(function(response) {
            var tmpData = response.data;
            if (response.data.success){
                self.cancel();
                self.data = tmpData.data.groups;
                $rootScope.$broadcast('group.updated', tmpData.data);
            }else{

            }
            
            jQuery('#categories-message').html(tmpData.message).show();
            jQuery.showStatusDialog({show: false});
            jQuery.scrollTo('#categories-message', 800, {offset: -35});
        }, function(rejectReason) {
            console.log("request error");
            console.dir(rejectReason);
        });
        
    };
    
    this.edit = function edit() {
        self.isEditMode = true;
        self.rows = [];
        $timeout(function(){
            self.rows = angular.copy(self.group);
        });
    };
    
    this.cancel = function cancel(){
        self.isEditMode = false;
        self.group = [];
        ld.remove(self.rows);
        $timeout(function(){
            self.insertRow();
        });
        
    };
    
})
.directive('groupRowsLoaded', function() {
    return function(scope, element, attrs) {
        if (angular.isUndefined(scope.row.id)){
            scope.row.id = scope.$index + 1;
        }
        scope.row.name = ld.stripslashes(scope.row.name);
    };
});
