'use strict';

var catalog = angular.module('GI-Catalog', ['pasvaz.bindonce', 'ngAnimate', 'ngClipboard'])
    .run(function($window, $http){
        function trim(x) {
            return x.replace(/^\s+|\s+$/gm,'');
        }
        
        function stripslashes(str) {
            if (str) {
                    str=str.replace(/\\'/g,'\'');
                    str=str.replace(/\\"/g,'"');
                    str=str.replace(/\\0/g,'\0');
                    str=str.replace(/\\\\/g,'\\');
            }
            return str;
        }
        ld.mixin({'trim': trim, 'stripslashes': stripslashes});
        
    })
    .constant('URI', catalogData.URI)
    .constant('QUERY_ITEM_URL', catalogData.query_item_url)
    .constant('QUERY_CATALOGID_URL', catalogData.query_catalogid_url)
    .constant('AJAX_URL', catalogData.ajax_url)
    .constant('TEMPLATE_URI', catalogData.URI + 'includes/views/site/templates/')
    .constant('CATEGORY_DATA', catalogData.catdata)
    .constant('ITEM_ID', catalogData.item_id)
    .constant('NONCE', catalogData.nonce)
    .constant('SHOW_SEARCH_BAR', catalogData.show_search_bar)
    .constant('SHOW_PAGINATION', catalogData.show_pagination)
    .constant('ITEMS_PER_PAGE', catalogData.items_per_page)
    .constant('COLLAPSIBLE_ACCORDION', catalogData.collapsible_accordion)
    .constant('HIDE_SINGLETAB_HEADER', catalogData.hide_singletab_header)
    .animation('.repeated-item', function() {
        return {
          enter : function(element, done) {
            element.css('opacity',0);
            jQuery(element).animate({
              opacity: 1
            }, done);

            // optional onDone or onCancel callback
            // function to handle any post-animation
            // cleanup operations
            return function(isCancelled) {
              if(isCancelled) {
                jQuery(element).stop();
              }
            }
          },
          leave : function(element, done) {
            element.css('opacity', 1);
            jQuery(element).animate({
              opacity: 0
            }, done);

            // optional onDone or onCancel callback
            // function to handle any post-animation
            // cleanup operations
            return function(isCancelled) {
              if(isCancelled) {
                jQuery(element).stop();
              }
            }
          },
          move : function(element, done) {
            element.css('opacity', 0);
            jQuery(element).animate({
              opacity: 1
            }, done);

            // optional onDone or onCancel callback
            // function to handle any post-animation
            // cleanup operations
            return function(isCancelled) {
              if(isCancelled) {
                jQuery(element).stop();
              }
            }
          },

          // you can also capture these animation events
          addClass : function(element, className, done) {},
          removeClass : function(element, className, done) {}
        }
    })
    .config(['$httpProvider', function($httpProvider) {
        $httpProvider.defaults.headers.post = {
            'Content-Type': 'application/x-www-form-urlencoded; charset=UTF-8'
        };
        //$httpProvider.interceptors.push('requestRejector');
        // Removing 'requestRecoverer' will result to failed request
        //$httpProvider.interceptors.push('responseRecoverer');
    }])
    .factory('requestRejector', ['$q', function($q) {
        var requestRejector = {
            request: function(config) {
                return $q.reject('requestRejector');
            }
        };
        return requestRejector;
    }])
    .factory('responseRecoverer', ['$q', '$injector', function($q, $injector) {
        var responseRecoverer = {
            responseError: function(response) {
                //refer to the status code reference at http://www.w3.org/Protocols/rfc2616/rfc2616-sec10.html
                if (response.status == 0) {
                    // may be offline
                    //uncomment below to retry the request
                    /*var $http = $injector.get('$http');
                    return $http(response.config);*/
                } else {
                    return $q.reject(response);
                }
            },
            /*requestError: function(response) {
                console.log("reloading");
                if (response.message === "reload") {
                    return response.data.config;
                }
            }*/
        };
        return responseRecoverer;
    }])
    .filter('text', function() {
        return function(str) {
            return ld.stripslashes(str);
        };
    })
    .filter('html', function($sce) {
        return function(input) {
            return $sce.trustAsHtml(ld.stripslashes(input));
        };
    });
    
angular.element("#gicatalog-widget, #gicatalog-shortcode").ready(function() {
    if (jQuery.trim(catalogData.fb_app_id)!=='') {
        jQuery('body').prepend('<div id="fb-root"></div>');
		//issue with loading when flash content is on page... bypassed the loading with accordion content to give it a delay
        /*window.fbAsyncInit = function() {
            FB.init({
                appId: catalogData.fb_app_id,
                xfbml: false,
                version: 'v2.1'
            });
        };
        (function(d, s, id) {
        var js, fjs = d.getElementsByTagName(s)[0];
                if (d.getElementById(id))
                return;
                js = d.createElement(s);
                js.id = id;
                js.src = "//connect.facebook.net/en_US/sdk.js";
                fjs.parentNode.insertBefore(js, fjs);
        }(document, 'script', 'facebook-jssdk'));*/
    }
    angular.bootstrap("#gicatalog-widget, #gicatalog-shortcode", ['GI-Catalog']);
});